@@ -114,15 +114,19 @@ register_element_cls('w:sectPr', CT_SectPr)
 register_element_cls('w:type',   CT_SectType)
 
 from docx.oxml.table import (
-    CT_Row, CT_Tbl, CT_TblGrid, CT_TblGridCol, CT_TblPr, CT_Tc
+    CT_Row, CT_Tbl, CT_TblGrid, CT_TblGridCol, CT_TblLayoutType, CT_TblPr,
+    CT_TblWidth, CT_Tc, CT_TcPr
 )
-register_element_cls('w:gridCol',  CT_TblGridCol)
-register_element_cls('w:tbl',      CT_Tbl)
-register_element_cls('w:tblGrid',  CT_TblGrid)
-register_element_cls('w:tblPr',    CT_TblPr)
-register_element_cls('w:tblStyle', CT_String)
-register_element_cls('w:tc',       CT_Tc)
-register_element_cls('w:tr',       CT_Row)
+register_element_cls('w:gridCol',   CT_TblGridCol)
+register_element_cls('w:tbl',       CT_Tbl)
+register_element_cls('w:tblGrid',   CT_TblGrid)
+register_element_cls('w:tblLayout', CT_TblLayoutType)
+register_element_cls('w:tblPr',     CT_TblPr)
+register_element_cls('w:tblStyle',  CT_String)
+register_element_cls('w:tc',        CT_Tc)
+register_element_cls('w:tcPr',      CT_TcPr)
+register_element_cls('w:tcW',       CT_TblWidth)
+register_element_cls('w:tr',        CT_Row)
 
 from docx.oxml.text import (
     CT_Br, CT_Jc, CT_P, CT_PPr, CT_R, CT_RPr, CT_Text, CT_Underline
