@@ -10,25 +10,24 @@ from __future__ import (
 
 from collections import Sequence
 
+from ..blkcntnr import BlockItemContainer
 from ..enum.section import WD_SECTION
 from ..opc.constants import RELATIONSHIP_TYPE as RT
 from ..opc.package import XmlPart
 from ..section import Section
 from ..shape import InlineShape
 from ..shared import lazyproperty, Parented
-from ..table import Table
-from ..text import Paragraph
 
 
 class DocumentPart(XmlPart):
     """
     Main document part of a WordprocessingML (WML) package, aka a .docx file.
     """
-    def add_paragraph(self):
+    def add_paragraph(self, text='', style=None):
         """
         Return a paragraph newly added to the end of body content.
         """
-        return self.body.add_paragraph()
+        return self.body.add_paragraph(text, style)
 
     def add_section(self, start_type=WD_SECTION.NEW_PAGE):
         """
@@ -113,35 +112,15 @@ class DocumentPart(XmlPart):
         return self.body.tables
 
 
-class _Body(Parented):
+class _Body(BlockItemContainer):
     """
     Proxy for ``<w:body>`` element in this document, having primarily a
     container role.
     """
     def __init__(self, body_elm, parent):
-        super(_Body, self).__init__(parent)
+        super(_Body, self).__init__(body_elm, parent)
         self._body = body_elm
 
-    def add_paragraph(self):
-        """
-        Return a paragraph newly added to the end of body content.
-        """
-        p = self._body.add_p()
-        return Paragraph(p, self)
-
-    def add_table(self, rows, cols):
-        """
-        Return a table having *rows* rows and *cols* cols, newly appended to
-        the main document story.
-        """
-        tbl = self._body.add_tbl()
-        table = Table(tbl, self)
-        for i in range(cols):
-            table.add_column()
-        for i in range(rows):
-            table.add_row()
-        return table
-
     def clear_content(self):
         """
         Return this |_Body| instance after clearing it of all content.
@@ -151,18 +130,6 @@ class _Body(Parented):
         self._body.clear_content()
         return self
 
-    @property
-    def paragraphs(self):
-        return [Paragraph(p, self) for p in self._body.p_lst]
-
-    @property
-    def tables(self):
-        """
-        A sequence containing all the tables in the document, in the order
-        they appear.
-        """
-        return [Table(tbl, self) for tbl in self._body.tbl_lst]
-
 
 class InlineShapes(Parented):
     """
