@@ -151,6 +151,18 @@ class DescribeTable(object):
 
 class Describe_Cell(object):
 
+    def it_can_add_a_paragraph(self, add_paragraph_fixture):
+        cell, expected_xml = add_paragraph_fixture
+        p = cell.add_paragraph()
+        assert cell._tc.xml == expected_xml
+        assert isinstance(p, Paragraph)
+
+    def it_can_add_a_table(self, add_table_fixture):
+        cell, expected_xml = add_table_fixture
+        table = cell.add_table(rows=0, cols=0)
+        assert cell._tc.xml == expected_xml
+        assert isinstance(table, Table)
+
     def it_provides_access_to_the_paragraphs_it_contains(
             self, paragraphs_fixture):
         cell = paragraphs_fixture
@@ -163,6 +175,18 @@ class Describe_Cell(object):
             count += 1
         assert count == 2
 
+    def it_provides_access_to_the_tables_it_contains(self, tables_fixture):
+        # test len(), iterable, and indexed access
+        cell, expected_count = tables_fixture
+        tables = cell.tables
+        assert len(tables) == expected_count
+        count = 0
+        for idx, table in enumerate(tables):
+            assert isinstance(table, Table)
+            assert tables[idx] is table
+            count += 1
+        assert count == expected_count
+
     def it_can_replace_its_content_with_a_string_of_text(
             self, text_set_fixture):
         cell, text, expected_xml = text_set_fixture
@@ -181,10 +205,48 @@ class Describe_Cell(object):
 
     # fixtures -------------------------------------------------------
 
+    @pytest.fixture(params=[
+        ('w:tc',       'w:tc/w:p'),
+        ('w:tc/w:p',   'w:tc/(w:p, w:p)'),
+        ('w:tc/w:tbl', 'w:tc/(w:tbl, w:p)'),
+    ])
+    def add_paragraph_fixture(self, request):
+        tc_cxml, after_tc_cxml = request.param
+        cell = _Cell(element(tc_cxml), None)
+        expected_xml = xml(after_tc_cxml)
+        return cell, expected_xml
+
+    @pytest.fixture(params=[
+        ('w:tc',     'w:tc/(w:tbl'),
+        ('w:tc/w:p', 'w:tc/(w:p, w:tbl'),
+    ])
+    def add_table_fixture(self, request):
+        tc_cxml, after_tc_cxml = request.param
+        # the table has some overhead elements, also a blank para after since
+        # it's in a cell.
+        after_tc_cxml += (
+            '/(w:tblPr/w:tblW{w:type=auto,w:w=0},w:tblGrid),w:p)'
+        )
+        cell = _Cell(element(tc_cxml), None)
+        expected_xml = xml(after_tc_cxml)
+        return cell, expected_xml
+
     @pytest.fixture
     def paragraphs_fixture(self):
         return _Cell(element('w:tc/(w:p, w:p)'), None)
 
+    @pytest.fixture(params=[
+        ('w:tc',                   0),
+        ('w:tc/w:tbl',             1),
+        ('w:tc/(w:tbl,w:tbl)',     2),
+        ('w:tc/(w:p,w:tbl)',       1),
+        ('w:tc/(w:tbl,w:tbl,w:p)', 2),
+    ])
+    def tables_fixture(self, request):
+        cell_cxml, expected_count = request.param
+        cell = _Cell(element(cell_cxml), None)
+        return cell, expected_count
+
     @pytest.fixture(params=[
         ('w:tc/w:p', 'foobar',
          'w:tc/w:p/w:r/w:t"foobar"'),
